==> aria2-1.2.0.tar.bz2: aria2-1.2.0/src/LibsslTLSContext.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_LIBSSL_TLS_CONTEXT_H_
#define _D_LIBSSL_TLS_CONTEXT_H_

#include "common.h"

#include <string>

# include <openssl/ssl.h>

#include "DlAbortEx.h"

namespace aria2 {

class Logger;

class TLSContext {
private:
  SSL_CTX* _sslCtx;

  bool _good;

  bool _peerVerificationEnabled;

  Logger* _logger;
public:
  TLSContext();

  ~TLSContext();

  // private key `keyfile' must be decrypted.
  void addClientKeyFile(const std::string& certfile,
			const std::string& keyfile) throw(DlAbortEx);

  // certfile can contain multiple certificates.
  void addTrustedCACertFile(const std::string& certfile) throw(DlAbortEx);

  bool good() const;

  bool bad() const;

  SSL_CTX* getSSLCtx() const;
  
  void enablePeerVerification();

  void disablePeerVerification();

  bool peerVerificationEnabled() const;
};

} // namespace aria2

#endif // _D_LIBSSL_TLS_CONTEXT_H_

==> aria2-1.4.1.tar.bz2: aria2-1.4.1/src/LibsslTLSContext.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_LIBSSL_TLS_CONTEXT_H_
#define _D_LIBSSL_TLS_CONTEXT_H_

#include "common.h"

#include <string>

# include <openssl/ssl.h>

#include "DlAbortEx.h"

namespace aria2 {

class Logger;

class TLSContext {
private:
  SSL_CTX* _sslCtx;

  bool _good;

  bool _peerVerificationEnabled;

  Logger* _logger;
public:
  TLSContext();

  ~TLSContext();

  // private key `keyfile' must be decrypted.
  void addClientKeyFile(const std::string& certfile,
			const std::string& keyfile) throw(DlAbortEx);

  // certfile can contain multiple certificates.
  void addTrustedCACertFile(const std::string& certfile) throw(DlAbortEx);

  bool good() const;

  bool bad() const;

  SSL_CTX* getSSLCtx() const
  {
    return _sslCtx;
  }
  
  void enablePeerVerification();

  void disablePeerVerification();

  bool peerVerificationEnabled() const
  {
    return _peerVerificationEnabled;
  }

};

} // namespace aria2

#endif // _D_LIBSSL_TLS_CONTEXT_H_
